@@ -9,7 +9,7 @@ Simple viewer for NotDB Databases
 Full documentation is avaliable on [Github](https://github.com/nawafalqari/NotDB_Viewer#readme)
 '''
 
-from .app import create_app, viewer_html
+from app import create_app, viewer_html
 
-__version__ = '1.2.6'
+__version__ = '1.3.0'
 __all__ = ['create_app', 'viewer_html']
\ No newline at end of file
