@@ -4,9 +4,23 @@ import pyonr
 import os
 from getpass import getpass
 from bcrypt import checkpw as _checkpw
-from .app import create_app
+from app import create_app
 
-from __init__ import __version__ as v
+def read(rel_path):
+    import codecs
+    here = os.path.abspath(os.path.dirname(__file__))
+    with codecs.open(os.path.join(here, rel_path), 'r') as fp:
+        return fp.read()
+
+def get_version(rel_path):
+    for line in read(rel_path).splitlines():
+        if line.startswith('__version__'):
+            delim = '"' if '"' in line else "'"
+            return line.split(delim)[1]
+    else:
+        raise RuntimeError("Unable to find version string.")
+
+v = get_version('__init__.py')
 
 def main():
    pass
